--- layout: none search: exclude ---

# Tooltip Demo

This page is purposely separated out from the rest of theme so you can see the bare minimum code to add to a page, without all the other theme's code getting in the way.

Content in the tooltips (actually "popovers" according to Bootstrap lingo) can be pulled in dynamically by placing the JSON file on a remote host.

Note: Make sure you view the file source so you can read the notes I've added in code comments.

Basketball

Baseball

Football

Soccer